Glossary
********

.. glossary::

   cross-sectional
      A data structure where the 'innermost' dimension is not a time dimension.
      Contrast with :term:`flat`, :term:`time series`.

   data flow
      A collection of one or more data sets sharing the same structure.

   flat
      A data set that is not grouped using SeriesKeys.

   information
      Data and :term:`metadata`.

   information model
      A description of how :term:`information` is organized, providing semantics: specific terms, their meanings, and their relationships.
      The SDMX IM is one information model.

   metadata
      Information *about* data.
      For instance, [1.2, 3.4, 4.5] are data points, or observations.
      Metadata for these data might include:

      - what concept is being measured,
      - the units for the measurements,
      - labels in one or more dimensions for what the three points means, or
      - info about how the data was produced, and by whom.

   time series
      A data structure where the 'innermost' dimension—the one that varies from one observation to the next—is time-related.
      Contrast with :term:`cross-sectional`, :term:`flat`.
